Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(265)

Unified Diff: chrome/browser/ui/ash/launcher/chrome_launcher_controller.h

Issue 2765563002: Move and rename Chrome's AppLauncherId to ash::AppLaunchId. (Closed)
Patch Set: Add example commment. Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/ash/launcher/chrome_launcher_controller.h
diff --git a/chrome/browser/ui/ash/launcher/chrome_launcher_controller.h b/chrome/browser/ui/ash/launcher/chrome_launcher_controller.h
index 6781e7b38312156c09cb57e5d8e9956e1fc99d5f..54af079df786d515f976961c4faf01d234ce04a1 100644
--- a/chrome/browser/ui/ash/launcher/chrome_launcher_controller.h
+++ b/chrome/browser/ui/ash/launcher/chrome_launcher_controller.h
@@ -9,12 +9,12 @@
#include <string>
#include <vector>
+#include "ash/public/cpp/app_launch_id.h"
#include "ash/public/cpp/shelf_item.h"
#include "ash/public/interfaces/shelf.mojom.h"
#include "chrome/browser/ui/app_icon_loader.h"
#include "chrome/browser/ui/app_icon_loader_delegate.h"
#include "chrome/browser/ui/app_list/app_list_controller_delegate.h"
-#include "chrome/browser/ui/ash/app_launcher_id.h"
#include "chrome/browser/ui/ash/launcher/launcher_item_controller.h"
#include "chrome/browser/ui/ash/launcher/settings_window_observer.h"
#include "mojo/public/cpp/bindings/associated_binding.h"
@@ -132,9 +132,9 @@ class ChromeLauncherController : public ash::mojom::ShelfObserver,
// Returns true if the specified item is for a platform app.
virtual bool IsPlatformApp(ash::ShelfID id) = 0;
// Opens a new instance of the application identified by the AppLauncherId.
// Used by the app-list, and by pinned-app shelf items.
- void LaunchApp(ash::AppLauncherId id,
+ void LaunchApp(ash::AppLaunchId id,
ash::ShelfLaunchSource source,
int event_flags);
@@ -132,9 +132,9 @@ class ChromeLauncherController : public ash::mojom::ShelfObserver,
// Returns true if the specified item is for a platform app.
virtual bool IsPlatformApp(ash::ShelfID id) = 0;
- // Opens a new instance of the application identified by the AppLauncherId.
+ // Opens a new instance of the application identified by the AppLaunchId.
// Used by the app-list, and by pinned-app shelf items.

Powered by Google App Engine
This is Rietveld 408576698